<?php

namespace Litecms\WithdrawSetting\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\WithdrawSetting\Http\Requests\WithdrawSettingRequest;
use Litecms\WithdrawSetting\Interfaces\WithdrawSettingRepositoryInterface;
use Litecms\WithdrawSetting\Models\WithdrawSetting;

/**
 * Resource controller class for withdraw_setting.
 */
class WithdrawSettingResourceController extends BaseController
{

    /**
     * Initialize withdraw_setting resource controller.
     *
     * @param type WithdrawSettingRepositoryInterface $withdraw_setting
     *
     * @return null
     */
    public function __construct(WithdrawSettingRepositoryInterface $withdraw_setting)
    {
        parent::__construct();
        $this->repository = $withdraw_setting;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\WithdrawSetting\Repositories\Criteria\WithdrawSettingResourceCriteria::class);
    }

    /**
     * Display a list of withdraw_setting.
     *
     * @return Response
     */
    public function index(WithdrawSettingRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\WithdrawSetting\Repositories\Presenter\WithdrawSettingPresenter::class)
                ->$function();
        }

        $withdraw_settings = $this->repository->paginate();

        return $this->response->title(trans('withdraw_setting::withdraw_setting.names'))
            ->view('withdraw_setting::withdraw_setting.index', true)
            ->data(compact('withdraw_settings'))
            ->output();
    }

    /**
     * Display withdraw_setting.
     *
     * @param Request $request
     * @param Model   $withdraw_setting
     *
     * @return Response
     */
    public function show(WithdrawSettingRequest $request, WithdrawSetting $withdraw_setting)
    {

        if ($withdraw_setting->exists) {
            $view = 'withdraw_setting::withdraw_setting.show';
        } else {
            $view = 'withdraw_setting::withdraw_setting.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('withdraw_setting::withdraw_setting.name'))
            ->data(compact('withdraw_setting'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new withdraw_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(WithdrawSettingRequest $request)
    {

        $withdraw_setting = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('withdraw_setting::withdraw_setting.name')) 
            ->view('withdraw_setting::withdraw_setting.create', true) 
            ->data(compact('withdraw_setting'))
            ->output();
    }

    /**
     * Create new withdraw_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(WithdrawSettingRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $withdraw_setting                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('withdraw_setting::withdraw_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('withdraw_setting/withdraw_setting/' . $withdraw_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/withdraw_setting/withdraw_setting'))
                ->redirect();
        }

    }

    /**
     * Show withdraw_setting for editing.
     *
     * @param Request $request
     * @param Model   $withdraw_setting
     *
     * @return Response
     */
    public function edit(WithdrawSettingRequest $request, WithdrawSetting $withdraw_setting)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('withdraw_setting::withdraw_setting.name'))
            ->view('withdraw_setting::withdraw_setting.edit', true)
            ->data(compact('withdraw_setting'))
            ->output();
    }

    /**
     * Update the withdraw_setting.
     *
     * @param Request $request
     * @param Model   $withdraw_setting
     *
     * @return Response
     */
    public function update(WithdrawSettingRequest $request, WithdrawSetting $withdraw_setting)
    {
        try {
            $attributes = $request->all();

            $withdraw_setting->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('withdraw_setting::withdraw_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('withdraw_setting/withdraw_setting/' . $withdraw_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('withdraw_setting/withdraw_setting/' . $withdraw_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the withdraw_setting.
     *
     * @param Model   $withdraw_setting
     *
     * @return Response
     */
    public function destroy(WithdrawSettingRequest $request, WithdrawSetting $withdraw_setting)
    {
        try {

            $withdraw_setting->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('withdraw_setting::withdraw_setting.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('withdraw_setting/withdraw_setting/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('withdraw_setting/withdraw_setting/' . $withdraw_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple withdraw_setting.
     *
     * @param Model   $withdraw_setting
     *
     * @return Response
     */
    public function delete(WithdrawSettingRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('withdraw_setting::withdraw_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('withdraw_setting/withdraw_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/withdraw_setting/withdraw_setting'))
                ->redirect();
        }

    }

    /**
     * Restore deleted withdraw_settings.
     *
     * @param Model   $withdraw_setting
     *
     * @return Response
     */
    public function restore(WithdrawSettingRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('withdraw_setting::withdraw_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/withdraw_setting/withdraw_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/withdraw_setting/withdraw_setting/'))
                ->redirect();
        }

    }

}
