<?php

namespace Litecms\WithdrawSetting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\WithdrawSetting\Models\WithdrawSetting;

class WithdrawSettingPolicy
{

    /**
     * Determine if the given user can view the withdraw_setting.
     *
     * @param UserPolicy $user
     * @param WithdrawSetting $withdraw_setting
     *
     * @return bool
     */
    public function view(UserPolicy $user, WithdrawSetting $withdraw_setting)
    {
        if ($user->canDo('withdraw_setting.withdraw_setting.view') && $user->isAdmin()) {
            return true;
        }

        return $withdraw_setting->user_id == user_id() && $withdraw_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a withdraw_setting.
     *
     * @param UserPolicy $user
     * @param WithdrawSetting $withdraw_setting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('withdraw_setting.withdraw_setting.create');
    }

    /**
     * Determine if the given user can update the given withdraw_setting.
     *
     * @param UserPolicy $user
     * @param WithdrawSetting $withdraw_setting
     *
     * @return bool
     */
    public function update(UserPolicy $user, WithdrawSetting $withdraw_setting)
    {
        if ($user->canDo('withdraw_setting.withdraw_setting.edit') && $user->isAdmin()) {
            return true;
        }

        return $withdraw_setting->user_id == user_id() && $withdraw_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given withdraw_setting.
     *
     * @param UserPolicy $user
     * @param WithdrawSetting $withdraw_setting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, WithdrawSetting $withdraw_setting)
    {
        return $withdraw_setting->user_id == user_id() && $withdraw_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given withdraw_setting.
     *
     * @param UserPolicy $user
     * @param WithdrawSetting $withdraw_setting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, WithdrawSetting $withdraw_setting)
    {
        if ($user->canDo('withdraw_setting.withdraw_setting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given withdraw_setting.
     *
     * @param UserPolicy $user
     * @param WithdrawSetting $withdraw_setting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, WithdrawSetting $withdraw_setting)
    {
        if ($user->canDo('withdraw_setting.withdraw_setting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
