<?php

namespace Litecms\WithdrawSetting\Providers;

use Illuminate\Support\ServiceProvider;

class WithdrawSettingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'withdraw_setting');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'withdraw_setting');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.withdraw_setting', function ($app) {
            return $this->app->make('Litecms\WithdrawSetting\WithdrawSetting');
        });

                // Bind WithdrawSetting to repository
        $this->app->bind(
            'Litecms\WithdrawSetting\Interfaces\WithdrawSettingRepositoryInterface',
            \Litecms\WithdrawSetting\Repositories\Eloquent\WithdrawSettingRepository::class
        );

        $this->app->register(\Litecms\WithdrawSetting\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\WithdrawSetting\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.withdraw_setting'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/withdraw_setting.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/withdraw_setting')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/withdraw_setting')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
